import router from './router'
import store from './store'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { getToken } from '@/utils/auth'

NProgress.configure({ showSpinner: false })

const whiteList = [
  '/index',
  '/login',
  '/auth-redirect',
  '/bind',
  '/register',
  '/news/index',
  '/news/newDetail',
  '/notice/index',
  '/supply/index',
  '/interaction/index',
  '/register/index',
  '/register/registerType',
  '/register/userRegister',
  '/register/companyRegister',
  '/biddingHall',
  '/authenticRight',
  '/authenticRight/login',
  '/project',
  '/policy',
  '/policyDetail',
  '/attestationDetail',
  '/noticeDetail',
  '/homestead/login',
  '/applicationForm',
  '/applicationList',
  '/certificateList',
  '/certificateSee',
  '/informationList',
  '/circulationList',
  '/circulationAdd',
  '/onlineHomeLogin',
  '/lawEnforcement',
  '/lawEnforcement/caseList',
  '/lawEnforcement/productsList',
  '/lawEnforcement/user',
  '/lawEnforcement/programme',
  '/lawEnforcement/programmeDetail',
  '/lawEnforcement/programmeModify',
  '/lawEnforcement/programmeApproval',
  '/lawEnforcement/complaint',
  '/lawEnforcement/reply',
  '/lawEnforcement/changePassword',
  '/lawEnforcement/feedback',
  '/lawEnforcement/feedbackForm',
  '/lawEnforcement/agreement',
  '/lawEnforcement/work',
  '/lawEnforcement/workDetail',
  '/lawEnforcement/caseDetail',
  '/lawEnforcement/login',
  '/lawEnforcement/indexComplaint',
  '/lawEnforcement/schemeDetail',
  '/lawEnforcement/waitingProcessing',
  '/lawEnforcement/complaintAdd',
  '/homesteadLogin',
  '/yinnongLogin',
  '/lawEnforcement/userRegister',
  '/lawEnforcement/companyRegister',
  '/sunVillage/login',
  //阳光村务公众号 -- 待删
  '/sunVillage/index',
  '/sunVillage/latestReport', //最新报道列表
  '/sunVillage/latestReport/details',  //最新报道详情
  '/sunVillage/importantItems',   //重大事项-列表
  '/sunVillage/importantItems/details', //重大事项-详情
  '/sunVillage/public',  //三务公开
  '/sunVillage/public/details', //三务公开-详情
  '/sunVillage/financial', //惠民金融
  '/sunVillage/financial/details', //惠民金融-详情
  '/sunVillage/financial/products', //惠民金融 - 理财产品
  '/sunVillage/financial/loan', //惠民金融 - 理财产品
  '/sunVillage/injoint', //三资公开-财务公开
  '/sunVillage/injoint/meansOf', //三资公开-清产核资
  '/sunVillage/injoint/meansOf_desc', //三资公开-清产核资-详情页
  '/sunVillage/injoint/assetsPublic',  //三资公开-资产公开
  '/sunVillage/injoint/publicResources', //三资公开-资源公开
  //阳光村务公众号 -- 待删
]

router.beforeEach((to, from, next) => {
  NProgress.start()
  if (getToken()) {
    /* has token*/
    if (to.path === '/login') {
      next({ path: '/' })
      NProgress.done()
    } else {
      if (store.getters.roles.length === 0) {
        next()
        // 判断当前用户是否已拉取完user_info信息
        store.dispatch('GetInfo').then(res => {
          // 拉取user_info
          const roles = res.roles
          // store.dispatch('GenerateRoutes', { roles }).then(accessRoutes => {
          //   // 根据roles权限生成可访问的路由表
          //   router.addRoutes(accessRoutes) // 动态添加可访问路由表
          //   next({ ...to, replace: true }) // hack方法 确保addRoutes已完成
          // })
          next()
        }).catch(err => {
          store.dispatch('LogOut').then(() => {
            // Message.error(err)
            if ('/authenticRight/index'.indexOf(to.path) !== -1) {
              next({ path: '/authenticRight/login' })
            } else if ('/homestead/index'.indexOf(to.path) !== -1) {
              next({ path: '/homestead/login' })
            } else if (to.path.indexOf('/onlineHome') !== -1) {
              next(`/onlineHomeLogin`)
            } else if (to.path.indexOf('/yinnong') !== -1) {
              next(`/yinnongLogin`)
            } else if (to.path.indexOf('/homesteadSurvey') !== -1) {
              next(`/homesteadLogin`)
            } else if (to.path.indexOf('/lawEnforcement') !== -1) {
              next(`//lawEnforcement/login`)
            } else if (to.path.indexOf('/sunVillage') !== -1) {
              next(`/sunVillage/login`)
            } else {
              next({ path: '/' })
            }
          })
        })
      } else {
        next()
      }
    }
  } else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      console.log(to.path)
      next()
    } else {
      if ('/authenticRight/index'.indexOf(to.path) !== -1) {
        next(`/authenticRight/login?redirect=${to.fullPath}`)
      } else if ('/homestead/index'.indexOf(to.path) !== -1) {
        next(`/homestead/login?redirect=${to.fullPath}`)
      } else if (to.path.indexOf('/onlineHome') !== -1) {
        next(`/onlineHomeLogin`)
      } else if (to.path.indexOf('/yinnong') !== -1) {
        next(`/yinnongLogin`)
      } else if (to.path.indexOf('/homesteadSurvey') !== -1) {
        next(`/homesteadLogin`)
      } else if (to.path.indexOf('/lawEnforcement') !== -1) {
        next(`/lawEnforcement/login?redirect=${to.fullPath}`)
      } else if (to.path.indexOf('/sunVillage') !== -1) {
        next(`/sunVillage/login`)
      } else {
        next(`/login?redirect=${to.fullPath}`)
      }

      //  // 否则全部重定向到登录页
      //next('/index');
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  NProgress.done()
})
